# LiveKit Plugins Anthropic

Agent Framework plugin for services from Anthropic.

## Installation

```bash
pip install livekit-plugins-anthropic
```

## Pre-requisites

You'll need an API key from Anthropic. It can be set as an environment variable: `ANTHROPIC_API_KEY`
